
;       Breathing Teapot movie

;       This program should be run whilst editing the drawing file
;       TPBR.DWG, which contains the teapot as a block definition
;       and has a camera, light, and scene named S already created with
;       the AutoShade Lisp commands.

;       Designed and implemented by John Walker

;       Instructions:

;          ACAD
;             2
;             TPBR
;             (load "tpbr")       { This file }
;             tp                  { Make filmrolls }
;             tps                 { Make scripts }
;             quit y

;          SHADE
;             Pick script
;             Select TPBR as script
;             { AutoShade makes the renderings }

;          AFEGA -mtpbr <tpbr.mvi
;             { AutoFlix compiles the movie into TPBR.MOV}

;       Utility routine to make a sequence of filmtrolls

(defun tmk (f lf)
   (while (<= f lf)
      (setq ang (* ainc f))
      (command "insert" "teapot"
         '(10 10) "XYZ"
         (- 1.0 (* 0.2 (sin ang)))
         (- 1.0 (* 0.2 (sin ang)))
         (+ 1.0 (* 0.4 (sin ang)))
         0
      )
      (command "filmroll" (strcat "tpf"
         (itoa f)))
      (setq f (1+ f))
      (setq ang (+ ang ainc))
      (command "erase" (entlast) "")
   )
)

;       Command to make teapot filmroll files

(defun C:TP ()
   (setq nf 36)
   (setq ainc (/ (* 2.0 pi) nf))
   (command "layer" "make" "teapot" "")
   (tmk 0 9)
   (tmk 27 35)
)
;
;       Create AutoShade script and AutoFlix command file.  Note that
;       the command counts on automatic recognition of re-used frames
;       and exploits temporal symmetry in the motion of the teapot.
;

;       Utility routine to write AutoShade script file

(defun tsmk (f nf inc)
   (while (/= f nf)
      (setq s (strcat "tpf" (itoa f)))
      (write-line (strcat "open " s) af)
      (write-line "scene s" af)
      (write-line "spercent -1" af)
      (write-line "lens 45" af)
      (write-line (strcat "fullshade " s)
         af)
      (setq f (+ f inc))
   )
)

;       Utility routine to write AutoFlix command file

(defun tmmk (f nf inc)
   (while (/= f nf)
      (write-line (strcat "tpf" (itoa f)) af)
      (setq f (+ f inc))
   )
)

;       Command to generate script and command files

(defun C:TPS ()
   (setq af (open "tpbr.scr" "w"))
   (write-line "record on" af)
   (tsmk 0 10 1)
   (tsmk 27 36 1)
   (close af)
   (setq af (open "tpbr.mvi" "w"))
   (tmmk 0 10 1)
   (tmmk 8 -1 -1)
   (tmmk 35 26 -1)
   (tmmk 28 36 1)
   (close af)
)
